@@ -10,9 +10,7 @@ class TestAntaresBenchmarks(TestCase):
 
     def test_antares_objects(self):
         ktt.test_angle_separation(
-            data_path("astro/antares_astro_objects_benchmark.csv"), 
-            "antares",
-            "antares"
+            data_path("astro/antares_astro_objects_benchmark.csv"), "antares", "antares"
         )
 
     def test_antares_coordinate_system_benchmarks(self):
@@ -22,22 +20,19 @@ class TestAntaresBenchmarks(TestCase):
             "antares",
         )
 
+
 class TestARCABenchmarks(TestCase):
     def setUp(self):
         self.angle_threshold = 0.02
 
     def test_arca_objects(self):
         ktt.test_angle_separation(
-            data_path("astro/ARCA_astro_objects_benchmark.csv"), 
-            "arca",
-            "arca"
+            data_path("astro/ARCA_astro_objects_benchmark.csv"), "arca", "arca"
         )
 
     def test_arca_coordinate_system_benchmarks(self):
         ktt.test_angle_separation(
-            data_path("astro/ARCA_coordinate_systems_benchmark.csv"),
-            "arca",
-            "arca"
+            data_path("astro/ARCA_coordinate_systems_benchmark.csv"), "arca", "arca"
         )
 
 
@@ -47,14 +42,10 @@ class TestORCABenchmarks(TestCase):
 
     def test_orca_objects(self):
         ktt.test_angle_separation(
-            data_path("astro/ORCA_astro_objects_benchmark.csv"),
-            "orca",
-            "orca"
+            data_path("astro/ORCA_astro_objects_benchmark.csv"), "orca", "orca"
         )
 
     def test_orca_coordinate_system_benchmarks(self):
         ktt.test_angle_separation(
-            data_path("astro/ORCA_coordinate_systems_benchmark.csv"),
-            "orca",
-            "orca"
+            data_path("astro/ORCA_coordinate_systems_benchmark.csv"), "orca", "orca"
         )
